nbqol.options
=============

.. automodule:: nbqol.options

   
   .. rubric:: Functions

   .. autosummary::
   
      get_ipython
      get_main_env_settings
      hide_warnings
      save_main_env_settings_to_json
      set_autoreload
   